@@ -1,5 +1,5 @@
 """This is is the "nester.py" module and it provdes one fucntion called print_lol() which prints lists that may or may not include nested lists."""
-def print_lol(the_list,indent=false,level=0):
+def print_lol(the_list,indent=False,level=0):
   """This function takes one positional argument called "the_list",
 which is any python list (of - possibly - nested lists).  Each data item in
 the provided list is (recusively) printed to the screen on it's own line."""
